=======================================================
VeryPDF HTML to Any Converter v 2.0
Copyright (C) 2005-2012 VeryPDF.com, Inc.
Web: http://www.verypdf.com/app/html-to-any/
Email: support@verypdf.com

VeryPDF HTML to Any Converter is designed to convert HTML files (or webpages)
to PDF; HTML to image formats including JPEG, TIFF, PNG, TGA, PS, EPS, PCX,
BMP, GIF, etc.; HTML to Office document formats including TXT, DOC, RTF, XLS,
CSV, etc.

Usage: html2any [options] <input file> <output file>

Options:
  -disable-external-links      : Remove external links.
  -disable-internal-links      : Remove internal links.
  -disable-javascript          : Do not allow web pages to run JavaScript.
  -debug-javascript            : Show javascript debugging output.
  -disable-smart-shrinking     : Disable the intelligent shrinking strategy
                                 used by WebKit that makes the pixel/DPI
                                 ratio none constant.
  -dpi <DPI>                   : Change the DPI explicitly (this has no
                                 effect on X11 based systems).
  -enable-plugins              : Enable installed plugins (such as flash).
  -ignore-load-errors          : Ignore pages that claim to have
                                 encountered an error during loading.
  -print-media-type            : Use print media-type instead of screen.
  -proxy <proxy>               : Use a proxy.
  -quiet                       : Be less verbose.
  -read-args-from-stdin        : Read command line arguments from stdin.
  -redirect-delay <msec>       : Wait some milliseconds for js-redirects
                                 (default 200).
  -encoding <encoding>         : Set the default text encoding, for input.
  -stop-slow-scripts           : Stop slow running JavaScript.
  -username <username>         : HTTP Authentication username.
  -password <password>         : HTTP authentication password.
  -zoom <float>                : Use this zoom factor (default 1).
  -f <int>                     : Specify the first page to convert.
  -l <int>                     : Specify the last page to convert.
  -margin-bottom <unitreal>    : Set the page bottom margin (default 10 mm).
  -margin-left <unitreal>      : Set the page left margin (default 10 mm).
  -margin-right <unitreal>     : Set the page right margin (default 10 mm).
  -margin-top <unitreal>       : Set the page top margin (default 10 mm).
  -minimum-font-size <int>     : Minimum font size (default 5).
  -no-background               : Do not retain background.
  -orientation <orientation>   : Set orientation: Landscape/Portrait. Default
                                 is Portrait.
  -page-height <unitreal>      : Page height (default unit millimeter).
  -page-width <unitreal>       : Page width  (default unit millimeter).
  -page-size <size>            : Set paper size to: A4, Letter, etc.
  -$ <regcode>                 : Register with a registration code.

For PDF only:
  -ownerpassword <passwd>      : Set owner password to output PDF file.
  -userpassword <passwd>       : Set user password to output PDF file.
  -key40bit                    : Set output PDF encryption strength as 40
                                 bits.
  -key128bit                   : Set output PDF encryption strength as 128
                                 bits.
  -permit <permissions>        : Apply permissions to the output PDF only if
                                 an owner password is given.
    printing                   : Allow high quality printing.
    lowprinting                : Allow low quality printing.
    modifycontents             : Allow modifying contents.
    assembly                   : Allow document assembly.
    copying                    : Allow copying.
    screenreader               : Allow screen reader.
    modifyannot                : Allow adding annotation.
    filling                    : Allow filling interactive PDF form.
    allowall                   : Allow all the above permissions and high
                                 quality printing.
  -lowquality                  : Generate low quality PDF/PS. Useful to
                                 shrink the result document space.
  -book                        : Generate a PDF book with a table of contents.
  -copies <number>             : Copies of the original HTML contained in the
                                 output PDF file (default 1).
  -collate                     : Collate when create multiple copies.
  -cookie <name> <value>       : Set an additional cookie (repeatable).
  -cookie-jar <path>           : Read and write cookies from and to the
                                 supplied cookie jar file.
  -cover <url>                 : Use HTML document as cover. It will be
                                 inserted before the toc with no headers
                                 and no footers.
  -custom-header <name> <value>: Set an additional HTTP header (repeatable).
  -default-header              : Add a default header, with the name of the
                                 page to the left, and the page number to
                                 the right.
  -replace <name> <value>      : Replace [name] with value in header and
                                 footer (repeatable).
  -disable-pdf-compression     : Do not use compression on PDF objects.
  -allow <path>                : Allow loading files in the specified folder.
                                 (repeatable)
  -disallow-local-file-access  : Do not allow a local file to load other
                                 local files except specified by -allow.
  -forms                       : Turn HTML form fields into PDF form fields.
  -grayscale                   : PDF will be generated in grayscale.
  -post <name> <value>         : Add an additional post field (repeatable).
  -post-file <name> <path>     : Post an additional file (repeatable).
  -toc                         : Insert a table of content in the beginning
                                 of the document.
  -user-style-sheet <url>      : Specify a user style sheet, to load with
                                 every page.
  -title <text>                : Specify the title of the generated PDF file.
                                 (The title of the first document is used if
                                 not specified).

For others except PDF:
  -r <int>                     : Resolution, in DPI (default 150).
  -xres <int>                  : X resolution, in DPI (default 150).
  -yres <int>                  : Y resolution, in DPI (default 150).
  -w <int>                     : Set image width, unit is pixel.
  -width <int>                 : Set image width, unit is pixel, same as -w.
  -h <int>                     : Set image height, unit is pixel.
  -height <int>                : Set image height, unit is pixel, same as -h.
  -mono                        : Generate a monochrome image file.
  -gray                        : Generate a grayscale image file.
  -dither <int>                : Enable or disable dithering when reduce the
                                 number of bits per pixel to bit (1, 4 or 8).
    -dither 0                  : Disable dithering.
    -dither 1                  : Floyd & Steinberg error diffusion.
    -dither 2                  : BAYER4x4, Bayer dot dithering (order 2
                                 dithering matrix).
    -dither 3                  : BAYER8x8, Bayer dot dithering (order 3
                                 dithering matrix).
    -dither 4                  : CLUSTER6x6, Clustered dot dithering
                                 (order 3 - 6x6 matrix).
    -dither 5                  : CLUSTER8x8, Clustered dot dithering
                                 (order 4 - 8x8 matrix).
    -dither 6                  : CLUSTER16x16, Clustered dot dithering
                                 (order 8 - 16x16 matrix).
    -dither 7                  : BAYER16x16, Bayer dot dithering (order
                                 4 dithering matrix).
  -compress <int>              : Set compression to TIFF format:
    -compress 1                : NONE compression.
    -compress 2                : CCITT modified Huffman RLE.
    -compress 3                : CCITT Group 3 fax encoding (1D).
    -compress 4                : CCITT Group 4 fax encoding.
    -compress 5                : LZW compression.
    -compress 6                : OJPEG compression.
    -compress 7                : JPEG DCT compression.
    -compress 8                : ADOBE_DEFLATE compression.
    -compress 32773            : PACKBITS compression.
    -compress 32809            : THUNDERSCAN compression.
    -compress 32946            : DEFLATE compression.
    -compress 88880            : 204x98  G4 ClassF TIFF.
    -compress 88881            : 204x196 G4 ClassF TIFF.
    -compress 88882            : 204x98  G3 ClassF TIFF.
    -compress 88883            : 204x196 G3 ClassF TIFF.
    -compress 88884            : CCITT Group 3 fax encoding (2D).
  -quality <int>               : Set quality to JPEG format, from 0 to 100.
  -multipage                   : Create multipage TIFF file.
  -aa <string>                 : Enable font anti-aliasing: yes/no, default
                                 is 'yes'.
  -aavec <string>              : Enable vector anti-aliasing: yes/no, default
                                 is 'yes'.
  -aaVector <string>           : Enable vector anti-aliasing: yes/no, default
                                 is 'yes'.
  -forcebwtif                  : Force to create black and white TIFF files.
  -threshold <int>             : Lightness threshold that is used to convert
                                 image to B&W.
  -forcexdpi <int>             : Force to set X DPI to image file.
  -forceydpi <int>             : Force to set Y DPI to image file.
  -tempname <string>           : Set filename template for output image files
  -tempname1                   : Apply filename template for single image
                                 file.
  -trimimage                   : Trim output image files, remove margins from
                                 output image files.
  -rotate <int>                : Rotate output image file at special angle.
  -fixed <fp>                  : Assume fixed-pitch (or tabular) text.
  -htmlmeta                    : Generate a simple HTML file, including the
                                 meta information.
  -enc <string>                : Output text encoding name.
  -eol <string>                : Output end-of-line convention: unix/dos/mac.
  -nopgbrk                     : Don't insert page breaks between pages in
                                 PDF to Text conversion.

Examples:
Apply permissions to the output PDF only if an owner password is given:
html2any -ownerpassword 123 -userpassword 456 -key128bit -permit printing
 modifyannot http://www.verypdf.com/ _permit.pdf

Generate a PDF book with a table of contents:
html2any -book http://www.verypdf.com/ _book.pdf

Collate when create multiple copies:
html2any -collate http://www.verypdf.com/ _collate.pdf

Copies of the original HTML contained in the output PDF file (default 1):
html2any -copies 3 http://www.verypdf.com/ _copies.pdf

Use HTML document as cover. It will be inserted before the toc with no headers
and no footers:
html2any -cover http://www.google.com/ http://www.verypdf.com/ _cover.pdf

Show JavaScript debugging output:
html2any -debug-javascript http://www.verypdf.com/ _debug-javascript.pdf

Remove external links:
html2any -disable-external-links http://www.verypdf.com/
 _disable-external-links.pdf

Remove internal links:
html2any -disable-internal-links http://www.verypdf.com/
 _disable-internal-links.pdf

Do not allow web pages to run javascript:
html2any -disable-javascript http://www.verypdf.com/
 _disable-javascript.pdf

Do not use lossless compression on PDF objects:
html2any -disable-pdf-compression http://www.verypdf.com/
 _disable-pdf-compression.pdf

Disable the intelligent shrinking strategy used by WebKit that makes the
pixel/dpi ratio none constant:
html2any -disable-smart-shrinking http://www.verypdf.com/
 _disable-smart-shrinking.pdf

Do not allowed conversion of a local file to read in other local files,
unless explecitily allowed with -allow:
html2any -disallow-local-file-access http://www.verypdf.com/
 _disallow-local-file-access.pdf

Change the DPI explicitly (this has no effect on X11 based systems):
html2any -dpi 400 http://www.verypdf.com/ _dpi.pdf

Enable installed plugins (such as flash):
html2any -enable-plugins http://www.verypdf.com/ _enable-plugins.pdf

Set the default text encoding, for input:
html2any -encoding UTF-8 http://www.verypdf.com/ _encoding.pdf

PDF will be generated in grayscale:
html2any -grayscale http://www.verypdf.com/ _grayscale.pdf

Set the page bottom margin (default 10 mm):
html2any -margin-bottom 10 http://www.verypdf.com/ _margin-bottom.pdf

Set the page left margin (default 10 mm):
html2any -margin-left 10 http://www.verypdf.com/ _margin-left.pdf

Set the page right margin (default 10 mm):
html2any -margin-right 10 http://www.verypdf.com/ _margin-right.pdf

Set the page top margin (default 10 mm):
html2any -margin-top 10 http://www.verypdf.com/ _margin-top.pdf

Do not retain background:
html2any -no-background http://www.verypdf.com/ _no-background.pdf

Page height (default unit millimeter):
html2any -page-height 100 http://www.verypdf.com/ _page-height.pdf

Page width  (default unit millimeter):
html2any -page-width 100 http://www.verypdf.com/ _page-width.pdf

Wait some milliseconds for js-redirects (default 200):
html2any -redirect-delay 20 http://www.verypdf.com/ _redirect-delay.pdf

Insert a table of content in the beginning of the document:
html2any -toc http://www.verypdf.com/ _toc.pdf

Use this zoom factor (default 1):
html2any -zoom 4 http://www.verypdf.com/ _zoom.pdf

Resolution, in DPI (default 150):
html2any -r 200 http://www.verypdf.com/ _r.jpg

X resolution, in DPI (default 150):
html2any -xres 150 http://www.verypdf.com/ _xres.jpg

Set image width, unit is pixel:
html2any -w 100 http://www.verypdf.com/ _w.jpg

Set image height, unit is pixel:
html2any -h 100 http://www.verypdf.com/ _h.jpg

Generate a grayscale image file:
html2any -gray http://www.verypdf.com/ _gray.jpg

Enable or disable dithering when reduce the number of bits per pixel to bit
(1, 4 or 8):
Html2any -dither 1 http://www.verypdf.com/ _dither.jpg

Set compression to TIFF format:
html2any -compress 2 http://www.verypdf.com/ _compress.tif

Create multipage TIFF file:
html2any -multipage http://www.verypdf.com/ _multipage.tif

Enable font anti-aliasing: yes/no, default is 'yes':
html2any -aa yes http://www.verypdf.com/ _aa.jpg

Enable vector anti-aliasing: yes/no, default is 'yes':
html2any -aavec yes http://www.verypdf.com/ _aavec.jpg

Force to create black and white TIFF files:
html2any -forcebwtif http://www.verypdf.com/ _forcebwtif.tif

Force to set X DPI to image file:
html2any -forcexdpi 200 http://www.verypdf.com/ _forcexdpi.jpg

Force to set Y DPI to image file:
html2any -forceydpi 200 http://www.verypdf.com/ _forceydpi.jpg

Set filename template for output image files:
html2any -tempname tempname http://www.verypdf.com/ _tempname.jpg

Apply filename template for single image file:
html2any -tempname1 http://www.verypdf.com/ _tempname1.jpg

Trim output image files, remove margins from output image files:
html2any -trimimage http://www.verypdf.com/ _trimimage.jpg

Rotate output image file at special angle:
html2any -rotate 45 http://www.verypdf.com/ _rotate.jpg

Output text encoding name:
html2any -enc UTF-8 http://www.verypdf.com/ _enc.jpg

Don't insert page breaks between pages in PDF to Text:
html2any -nopgbrk http://www.verypdf.com/ _nopgbrk.jpg